﻿using System.Collections.Concurrent;
using System.Collections.Generic;
using System.IO;
using System.Linq;

namespace DL.PhotoCollage.Core
{
    public class OrderedFileSystemPhotoRepository : IPhotoRepository
    {
        private readonly ConcurrentQueue<string> photoFilePaths;

        private readonly string rootDirectoryPath;

        public OrderedFileSystemPhotoRepository(string path)
        {
            this.photoFilePaths = new ConcurrentQueue<string>();
            this.rootDirectoryPath = path;
            this.LoadPathsFromFileSystem();
        }

        public bool HasPhotos
        {
            get { return !this.photoFilePaths.IsEmpty; }
        }

        public string NextPhotoFilePath
        {
            get
            {
                string path;

                if (!this.photoFilePaths.TryDequeue(out path))
                {
                    this.photoFilePaths.TryDequeue(out path);
                }

                this.photoFilePaths.Enqueue(path);
                return Path.Combine(this.rootDirectoryPath, path);
            }
        }

        private static IEnumerable<string> GetPhotoFileExtensions()
        {
            return new List<string> { "*.jpg", "*.jpeg", "*.png" };
        }

        private void LoadPathsFromFileSystem()
        {
            var paths = new List<string>();
            var directory = new DirectoryInfo(this.rootDirectoryPath);
            var extensions = GetPhotoFileExtensions();

            foreach (string extension in extensions)
            {
                var pathsFromExtension
                    = from file in directory.GetFiles(extension, SearchOption.AllDirectories).AsParallel()
                      select file.FullName.Replace(this.rootDirectoryPath, string.Empty).TrimStart(new[] { '\\' });
                paths.AddRange(pathsFromExtension);
            }

            var orderedPaths = paths.OrderBy(x => x);
            this.LoadPhotoPathsIntoQueue(orderedPaths);
        }

        private void LoadPhotoPathsIntoQueue(IEnumerable<string> paths)
        {
            foreach (var path in paths)
            {
                this.photoFilePaths.Enqueue(path);
            }
        }
    }
}
