using System;
using System.IO;

namespace DL.PhotoCollage.Core
{
    public class TextLogger : ILogger
    {
        private readonly string directory;

        public TextLogger(string directoryPath)
        {
            this.directory = Path.Combine(directoryPath, @"logs");
            Directory.CreateDirectory(this.directory);
        }

        public void Log(string message)
        {
            string fullPath = this.GetFullFilePath();

            using (StreamWriter writer = File.AppendText(fullPath))
            {
                writer.WriteLine(GetLogEntry(message));
                writer.Flush();
            }
        }

        public void Log(string message, string stackTrace)
        {
            string fullPath = this.GetFullFilePath();

            using (StreamWriter writer = File.AppendText(fullPath))
            {
                writer.WriteLine(GetLogEntry(message));
                writer.WriteLine("Stack Trace:");
                writer.WriteLine(stackTrace);
                writer.Flush();
            }
        }

        private static string GetLogEntry(string message)
        {
            string date = DateTime.Now.ToString();
            return string.Concat(date, "  ==>  ", message);
        }

        private static string GetFileName()
        {
            return "log-" + DateTime.Today.ToString("yyyy-MM-dd") + ".txt";
        }

        private string GetFullFilePath()
        {
            return Path.Combine(this.directory, GetFileName());
        }
    }
}