﻿using System;
using System.Collections.Concurrent;
using System.Windows;
using DL.PhotoCollage.Core;
using DL.PhotoCollage.UI.Screensaver.Views;
using DL.PhotoCollage.Wpf.Presentation;
using DL.PhotoCollage.Wpf.UserControls;

namespace DL.PhotoCollage.UI.Screensaver.Presentation
{
    internal class ScreensaverPresenter : CollagePresenterBase
    {
        private readonly ScreensaverView view;
       
        private bool hasMouseStartedMoving;

        private Point mousePosition;

        public ScreensaverPresenter(ControllerBase applicationController)
            : base(applicationController)
        {
            if (this.Controller.Configuration.IsRandom)
            {
                this.PhotoRespository = new RandomFileSystemPhotoRepository(this.Controller.Configuration.Directory);
            }
            else
            {
                this.PhotoRespository = new OrderedFileSystemPhotoRepository(this.Controller.Configuration.Directory);
            }
            
            this.ImageQueue = new ConcurrentQueue<ImageDisplayUserControl>();
            this.MaxInQueue = this.Controller.Configuration.NumberOfPhotos;
            this.view = new ScreensaverView(this);
            this.Controller.ShowWindow(this.view);
        }

        public void KeyDown()
        {
            this.Controller.ShutdownApplication();
        }

        public void MouseDown()
        {
            this.Controller.ShutdownApplication();
        }

        public void MouseMove(Point currentPosition)
        {
            try
            {
                if (!this.hasMouseStartedMoving)
                {
                    this.mousePosition = currentPosition;
                    this.hasMouseStartedMoving = true;
                }
                else
                {
                    if ((Math.Abs(this.mousePosition.X - currentPosition.X) > 10) ||
                        (Math.Abs(this.mousePosition.Y - currentPosition.Y) > 10))
                    {
                        this.Controller.ShutdownApplication();
                    }
                }
            }
            catch (Exception ex)
            {
                this.Controller.HandleError(ex, true);
                this.Controller.ShutdownApplication();
            }
        }

        protected override void AddControlToView(ImageDisplayUserControl control)
        {
            this.view.MainCanvas.Children.Add(control);
        }

        protected override bool DoesViewContainControl(ImageDisplayUserControl control)
        {
            return this.view.MainCanvas.Children.Contains(control);
        }

        protected override double GetViewActualHeight()
        {
            return this.view.ActualHeight;
        }

        protected override double GetViewActualWidth()
        {
            return this.view.ActualWidth;
        }

        protected override void RemoveControlFromView(ImageDisplayUserControl control)
        {
            this.view.MainCanvas.Children.Remove(control);
        }
    }
}
