﻿using System.Collections.Concurrent;
using DL.PhotoCollage.Core;
using DL.PhotoCollage.UI.StandAlone.Views;
using DL.PhotoCollage.Wpf.Presentation;
using DL.PhotoCollage.Wpf.UserControls;

namespace DL.PhotoCollage.UI.StandAlone.Presentation
{
    public class CollagePresenter : CollagePresenterBase
    {
        private readonly CollageView view;

        public CollagePresenter(StandAloneController applicationController)
            : base(applicationController)
        {
            if (this.Controller.Configuration.IsRandom)
            {
                this.PhotoRespository = new RandomFileSystemPhotoRepository(this.Controller.Configuration.Directory);
            }
            else
            {
                this.PhotoRespository = new OrderedFileSystemPhotoRepository(this.Controller.Configuration.Directory);
            }

            this.ImageQueue = new ConcurrentQueue<ImageDisplayUserControl>();
            this.MaxInQueue = this.Controller.Configuration.NumberOfPhotos;

            this.view = new CollageView(this);
            this.Controller.ShowWindow(this.view);
        }

        public void Close()
        {
            this.view.Close();
        }

        protected override void AddControlToView(ImageDisplayUserControl control)
        {
            this.view.MainCanvas.Children.Add(control);
        }

        protected override bool DoesViewContainControl(ImageDisplayUserControl control)
        {
            return this.view.MainCanvas.Children.Contains(control);
        }

        protected override double GetViewActualHeight()
        {
            return this.view.ActualHeight;
        }

        protected override double GetViewActualWidth()
        {
            return this.view.ActualWidth;
        }

        protected override void RemoveControlFromView(ImageDisplayUserControl control)
        {
            this.view.MainCanvas.Children.Remove(control);
        }
    }
}
